=========
ChangeLog
=========

All notable changes to this project will be documented in this file.

`Unreleased`_
=============

v0.1.4_
=======

* Move project forge to CodeBerg.org.
* Drop github actions scripts.
* Add azure-pipelines YAML files.

v0.1.3_
=======

* Add Python 3.11 beta wheels.

v0.1.2_
=======

* Actions: Fix sdist build command to use pyproject.toml

v0.1.1_
=======

* First Alpha
* Support decompression/inflation

.. History links
.. _Unreleased: https://github.com/miurahr/inflate64/compare/v0.1.4...HEAD
.. _v0.1.4: https://github.com/miurahr/inflate64/compare/v0.1.3...v0.1.4
.. _v0.1.3: https://github.com/miurahr/inflate64/compare/v0.1.2...v0.1.3
.. _v0.1.2: https://github.com/miurahr/inflate64/compare/v0.1.1...v0.1.2
.. _v0.1.1: https://github.com/miurahr/inflate64/compare/v0.1.0...v0.1.1
